@@ -3,6 +3,6 @@ from .config.info import __version__, __author__, __contact__, __github__
 
 __all__ = [
     "__version__", "__author__", "__contact__", "__github__",
-    "Transaction", "Building", "StoreInfo", "Transportation", "Kosis", "VworldData",
+    "Transaction", "Building", "StoreInfo", "Transportation", "Kosis", "VworldData", "Kamco", "Nts",
     "code_bdong", "get_vworld_data_api_info_by_dataframe", "get_vworld_data_api_info_by_dict",
 ]
